@@ -10,7 +10,19 @@ tqsdk.ta 模块包含了一批常用的技术指标计算函数
 import math
 
 import numpy as np
-import pandas as pd
+try:
+    import pandas as pd
+except ImportError as e:
+    err_msg = f"执行 import pandas 时发生错误： {e}。\n"
+    err_msg += """
+    当遇到此问题时，如果您是 windows 用户，并且安装的 pandas 版本大于等于 1.0.2，可以尝试以下解决方案之一，再重新运行程序即可。
+    （您使用的机器缺少 pandas 需要的运行时环境）
+    1. 到微软官网下载您机器上安装 python 对应版本的 vc_redist 文件运行安装即可。https://www.microsoft.com/en-us/download/details.aspx?id=48145 
+       vc_redist.x64.exe（64 位 python）、 vc_redist.x86.exe（32 位 python）
+    2. 卸载当前的 pandas (pip uninstall pandas)
+       安装 pandas 1.0.1 版本 (pip install pandas==1.0.1)
+    """
+    raise Exception(err_msg)
 
 import tqsdk.tafunc
 
@@ -30,10 +42,10 @@ def ATR(df, n):
     Example::
 
         # 获取 CFFEX.IF1903 合约的平均真实波幅
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import ATR
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         atr = ATR(klines, 14)
         print(atr.tr)  # 真实波幅
@@ -69,10 +81,10 @@ def BIAS(df, n):
     Example::
 
         # 获取 CFFEX.IF1903 合约的乖离率
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import BIAS
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         bias = BIAS(klines, 6)
         print(list(bias["bias"]))  # 乖离率
@@ -102,10 +114,10 @@ def BOLL(df, n, p):
     Example::
 
         # 获取 CFFEX.IF1903 合约的布林线
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import BOLL
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         boll=BOLL(klines, 26, 2)
         print(list(boll["mid"]))
@@ -143,10 +155,10 @@ def DMI(df, n, m):
     Example::
 
         # 获取 CFFEX.IF1903 合约的动向指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import DMI
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         dmi=DMI(klines, 14, 6)
         print(list(dmi["atr"]))
@@ -197,10 +209,10 @@ def KDJ(df, n, m1, m2):
     Example::
 
         # 获取 CFFEX.IF1903 合约的随机指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import KDJ
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         kdj = KDJ(klines, 9, 3, 3)
         print(list(kdj["k"]))
@@ -243,10 +255,10 @@ def MACD(df, short, long, m):
     Example::
 
         # 获取 CFFEX.IF1903 合约的异同移动平均线
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import MACD
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         macd = MACD(klines, 12, 26, 9)
         print(list(macd["diff"]))
@@ -327,10 +339,10 @@ def SAR(df, n, step, max):
     Example::
 
         # 获取 CFFEX.IF1903 合约的抛物线指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import SAR
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         sar=SAR(klines, 4, 0.02, 0.2)
         print(list(sar["sar"]))
@@ -362,10 +374,10 @@ def WR(df, n):
     Example::
 
         # 获取 CFFEX.IF1903 合约的威廉指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import WR
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         wr = WR(klines, 14)
         print(list(wr["wr"]))
@@ -394,10 +406,10 @@ def RSI(df, n):
     Example::
 
         # 获取 CFFEX.IF1903 合约的相对强弱指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import RSI
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         rsi = RSI(klines, 7)
         print(list(rsi["rsi"]))
@@ -425,10 +437,10 @@ def ASI(df):
     Example::
 
         # 获取 CFFEX.IF1903 合约的振动升降指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import ASI
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         asi = ASI(klines)
         print(list(asi["asi"]))
@@ -465,10 +477,10 @@ def VR(df, n):
     Example::
 
         # 获取 CFFEX.IF1903 合约的VR
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import VR
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         vr = VR(klines, 26)
         print(list(vr["vr"]))
@@ -499,10 +511,10 @@ def ARBR(df, n):
     Example::
 
         # 获取 CFFEX.IF1903 合约的人气意愿指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import ARBR
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         arbr = ARBR(klines, 26)
         print(list(arbr["ar"]))
@@ -541,10 +553,10 @@ def DMA(df, short, long, m):
     Example::
 
         # 获取 CFFEX.IF1903 合约的平均线差
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import DMA
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         dma = DMA(klines, 10, 50, 10)
         print(list(dma["ddd"]))
@@ -578,10 +590,10 @@ def EXPMA(df, p1, p2):
     Example::
 
         # 获取 CFFEX.IF1903 合约的指数加权移动平均线组合
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import EXPMA
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         expma = EXPMA(klines, 5, 10)
         print(list(expma["ma1"]))
@@ -615,10 +627,10 @@ def CR(df, n, m):
     Example::
 
         # 获取 CFFEX.IF1903 合约的CR能量
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import CR
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         cr = CR(klines, 26, 5)
         print(list(cr["cr"]))
@@ -652,10 +664,10 @@ def CCI(df, n):
     Example::
 
         # 获取 CFFEX.IF1903 合约的顺势指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import CCI
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         cci = CCI(klines, 14)
         print(list(cci["cci"]))
@@ -688,10 +700,10 @@ def OBV(df):
     Example::
 
         # 获取 CFFEX.IF1903 合约的能量潮
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import OBV
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         obv = OBV(klines)
         print(list(obv["obv"]))
@@ -721,10 +733,10 @@ def CDP(df, n):
     Example::
 
         # 获取 CFFEX.IF1903 合约的逆势操作指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import CDP
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         cdp = CDP(klines, 3)
         print(list(cdp["ah"]))
@@ -764,10 +776,10 @@ def HCL(df, n):
     Example::
 
         # 获取 CFFEX.IF1903 合约的均线通道指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import HCL
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         hcl = HCL(klines, 10)
         print(list(hcl["mah"]))
@@ -804,10 +816,10 @@ def ENV(df, n, k):
     Example::
 
         # 获取 CFFEX.IF1903 合约的包略线
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import ENV
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         env = ENV(klines, 14, 6)
         print(list(env["upper"]))
@@ -839,10 +851,10 @@ def MIKE(df, n):
     Example::
 
         # 获取 CFFEX.IF1903 合约的麦克指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import MIKE
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         mike = MIKE(klines, 12)
         print(list(mike["wr"]))
@@ -889,10 +901,10 @@ def PUBU(df, m):
     Example::
 
         # 获取 CFFEX.IF1903 合约的瀑布线
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import PUBU
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         pubu = PUBU(klines, 4)
         print(list(pubu["pb"]))
@@ -927,10 +939,10 @@ def BBI(df, n1, n2, n3, n4):
     Example::
 
         # 获取 CFFEX.IF1903 合约的多空指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import BBI
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         bbi = BBI(klines, 3, 6, 12, 24)
         print(list(bbi["bbi"]))
@@ -960,10 +972,10 @@ def DKX(df, m):
     Example::
 
         # 获取 CFFEX.IF1903 合约的多空线
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import DKX
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         dkx = DKX(klines, 10)
         print(list(dkx["b"]))
@@ -1004,10 +1016,10 @@ def BBIBOLL(df, n, m):
     Example::
 
         # 获取 CFFEX.IF1903 合约的多空布林线
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import BBIBOLL
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         bbiboll=BBIBOLL(klines,10,3)
         print(list(bbiboll["bbiboll"]))
@@ -1046,10 +1058,10 @@ def ADTM(df, n, m):
     Example::
 
         # 获取 CFFEX.IF1903 合约的动态买卖气指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import ADTM
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         adtm = ADTM(klines, 23, 8)
         print(list(adtm["adtm"]))
@@ -1087,10 +1099,10 @@ def B3612(df):
     Example::
 
         # 获取 CFFEX.IF1903 合约的三减六日乖离率
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import B3612
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         b3612=B3612(klines)
         print(list(b3612["b36"]))
@@ -1126,10 +1138,10 @@ def DBCD(df, n, m, t):
     Example::
 
         # 获取 CFFEX.IF1903 合约的异同离差乖离率
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import DBCD
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         dbcd=DBCD(klines, 5, 16, 76)
         print(list(dbcd["dbcd"]))
@@ -1169,10 +1181,10 @@ def DDI(df, n, n1, m, m1):
     Example::
 
         # 获取 CFFEX.IF1903 合约的方向标准离差指数
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import DDI
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         ddi = DDI(klines, 13, 30, 10, 5)
         print(list(ddi["ddi"]))
@@ -1217,10 +1229,10 @@ def KD(df, n, m1, m2):
     Example::
 
         # 获取 CFFEX.IF1903 合约的随机指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import KD
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         kd = KD(klines, 9, 3, 3)
         print(list(kd["k"]))
@@ -1257,10 +1269,10 @@ def LWR(df, n, m):
     Example::
 
         # 获取 CFFEX.IF1903 合约的威廉指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import LWR
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         lwr = LWR(klines, 9, 3)
         print(list(lwr["lwr"]))
@@ -1293,10 +1305,10 @@ def MASS(df, n1, n2):
     Example::
 
         # 获取 CFFEX.IF1903 合约的梅斯线
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import MASS
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         mass = MASS(klines, 9, 25)
         print(list(mass["mass"]))
@@ -1326,10 +1338,10 @@ def MFI(df, n):
     Example::
 
         # 获取 CFFEX.IF1903 合约的资金流量指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import MFI
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         mfi = MFI(klines, 14)
         print(list(mfi["mfi"]))
@@ -1360,10 +1372,10 @@ def MI(df, n):
     Example::
 
         # 获取 CFFEX.IF1903 合约的动量指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import MI
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         mi = MI(klines, 12)
         print(list(mi["a"]))
@@ -1399,10 +1411,10 @@ def MICD(df, n, n1, n2):
     Example::
 
         # 获取 CFFEX.IF1903 合约的异同离差动力指数
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import MICD
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         micd = MICD(klines, 3, 10, 20)
         print(list(micd["dif"]))
@@ -1438,10 +1450,10 @@ def MTM(df, n, n1):
     Example::
 
         # 获取 CFFEX.IF1903 合约的动力指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import MTM
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         mtm = MTM(klines, 6, 6)
         print(list(mtm["mtm"]))
@@ -1475,10 +1487,10 @@ def PRICEOSC(df, long, short):
     Example::
 
         # 获取 CFFEX.IF1903 合约的价格震荡指数
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth, TqSim
         from tqsdk.ta import PRICEOSC
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         priceosc = PRICEOSC(klines, 26, 12)
         print(list(priceosc["priceosc"]))
@@ -1513,7 +1525,7 @@ def PSY(df, n, m):
         from tqsdk import TqApi, TqSim
         from tqsdk.ta import PSY
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         psy = PSY(klines, 12, 6)
         print(list(psy["psy"]))
@@ -1546,7 +1558,7 @@ def QHLSR(df):
         from tqsdk import TqApi, TqSim
         from tqsdk.ta import QHLSR
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         ndf = QHLSR(klines)
         print(list(ndf["qhl5"]))
@@ -1590,7 +1602,7 @@ def RC(df, n):
         from tqsdk import TqApi, TqSim
         from tqsdk.ta import RC
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         rc = RC(klines, 50)
         print(list(rc["arc"]))
@@ -1626,7 +1638,7 @@ def RCCD(df, n, n1, n2):
         from tqsdk import TqApi, TqSim
         from tqsdk.ta import RCCD
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         rccd = RCCD(klines, 10, 21, 28)
         print(list(rccd["dif"]))
@@ -1662,10 +1674,10 @@ def ROC(df, n, m):
     Example::
 
         # 获取 CFFEX.IF1903 合约的变动速率
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import ROC
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         roc = ROC(klines, 24, 20)
         print(list(roc["roc"]))
@@ -1703,10 +1715,10 @@ def SLOWKD(df, n, m1, m2, m3):
     Example::
 
         # 获取 CFFEX.IF1903 合约的慢速KD
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import SLOWKD
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         slowkd = SLOWKD(klines, 9, 3, 3, 3)
         print(list(slowkd["k"]))
@@ -1741,10 +1753,10 @@ def SRDM(df, n):
     Example::
 
         # 获取 CFFEX.IF1903 合约的动向速度比率
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import SRDM
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         srdm = SRDM(klines, 30)
         print(list(srdm["srdm"]))
@@ -1784,10 +1796,10 @@ def SRMI(df, n):
     Example::
 
         # 获取 CFFEX.IF1903 合约的MI修正指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import SRMI
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         srmi = SRMI(klines, 9)
         print(list(srmi["a"]))
@@ -1826,10 +1838,10 @@ def ZDZB(df, n1, n2, n3):
     Example::
 
         # 获取 CFFEX.IF1903 合约的筑底指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import ZDZB
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         zdzb = ZDZB(klines, 50, 5, 20)
         print(list(zdzb["b"]))
@@ -1861,10 +1873,10 @@ def DPO(df):
     Example::
 
         # 获取 CFFEX.IF1903 合约的区间震荡线
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import DPO
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         dpo = DPO(klines)
         print(list(dpo["dpo"]))
@@ -1891,10 +1903,10 @@ def LON(df):
     Example::
 
         # 获取 CFFEX.IF1903 合约的长线指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import LON
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         lon = LON(klines)
         print(list(lon["lon"]))
@@ -1935,10 +1947,10 @@ def SHORT(df):
     Example::
 
         # 获取 CFFEX.IF1903 合约的短线指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import SHORT
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         short = SHORT(klines)
         print(list(short["short"]))
@@ -1981,10 +1993,10 @@ def MV(df, n, m):
     Example::
 
         # 获取 CFFEX.IF1903 合约的均量线
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import MV
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         mv = MV(klines, 10, 20)
         print(list(mv["mv1"]))
@@ -2018,10 +2030,10 @@ def WAD(df, n, m):
     Example::
 
         # 获取 CFFEX.IF1903 合约的威廉多空力度线
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import WAD
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         wad = WAD(klines, 10, 30)
         print(list(wad["a"]))
@@ -2059,10 +2071,10 @@ def AD(df):
     Example::
 
         # 获取 CFFEX.IF1903 合约的累积/派发指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import AD
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         ad = AD(klines)
         print(list(ad["ad"]))
@@ -2090,10 +2102,10 @@ def CCL(df):
     Example::
 
         # 获取 CFFEX.IF1903 合约的持仓异动指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import CCL
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         ccl = CCL(klines)
         print(list(ccl["ccl"]))
@@ -2124,10 +2136,10 @@ def CJL(df):
     Example::
 
         # 获取 CFFEX.IF1903 合约的成交量
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import CJL
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         ndf = CJL(klines)
         print(list(ndf["vol"]))
@@ -2157,10 +2169,10 @@ def OPI(df):
     Example::
 
         # 获取 CFFEX.IF1903 合约的持仓量
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import OPI
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         opi = OPI(klines)
         print(list(opi["opi"]))
@@ -2187,10 +2199,10 @@ def PVT(df):
     Example::
 
         # 获取 CFFEX.IF1903 合约的价量趋势指数
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import PVT
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         pvt = PVT(klines)
         print(list(pvt["pvt"]))
@@ -2221,10 +2233,10 @@ def VOSC(df, short, long):
     Example::
 
         # 获取 CFFEX.IF1903 合约的移动平均成交量指标
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import VOSC
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         vosc = VOSC(klines, 12, 26)
         print(list(vosc["vosc"]))
@@ -2253,10 +2265,10 @@ def VROC(df, n):
     Example::
 
         # 获取 CFFEX.IF1903 合约的量变动速率
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import VROC
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         vroc = VROC(klines, 12)
         print(list(vroc["vroc"]))
@@ -2285,10 +2297,10 @@ def VRSI(df, n):
     Example::
 
         # 获取 CFFEX.IF1903 合约的量相对强弱
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import VRSI
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         vrsi = VRSI(klines, 6)
         print(list(vrsi["vrsi"]))
@@ -2317,10 +2329,10 @@ def WVAD(df):
     Example::
 
         # 获取 CFFEX.IF1903 合约的威廉变异离散量
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import WVAD
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         wvad = WVAD(klines)
         print(list(wvad["wvad"]))
@@ -2349,10 +2361,10 @@ def MA(df, n):
     Example::
 
         # 获取 CFFEX.IF1903 合约的简单移动平均线
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import MA
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         ma = MA(klines, 30)
         print(list(ma["ma"]))
@@ -2382,10 +2394,10 @@ def SMA(df, n, m):
     Example::
 
         # 获取 CFFEX.IF1903 合约的扩展指数加权移动平均线
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import SMA
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         sma = SMA(klines, 5, 2)
         print(list(sma["sma"]))
@@ -2413,10 +2425,10 @@ def EMA(df, n):
     Example::
 
         # 获取 CFFEX.IF1903 合约的指数加权移动平均线
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import EMA
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         ema = EMA(klines, 10)
         print(list(ema["ema"]))
@@ -2444,10 +2456,10 @@ def EMA2(df, n):
     Example::
 
         # 获取 CFFEX.IF1903 合约的线性加权移动平均线
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import EMA2
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         ema2 = EMA2(klines, 10)
         print(list(ema2["ema2"]))
@@ -2475,10 +2487,10 @@ def TRMA(df, n):
     Example::
 
         # 获取 CFFEX.IF1903 合约的三角移动平均线
-        from tqsdk import TqApi, TqSim
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import TRMA
 
-        api = TqApi(TqSim())
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         klines = api.get_kline_serial("CFFEX.IF1903", 24 * 60 * 60)
         trma = TRMA(klines, 10)
         print(list(trma["trma"]))
@@ -2514,10 +2526,10 @@ def BS_VALUE(df, quote, r=0.025, v=None):
 
     Example1::
 
-        from tqsdk import TqApi
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import BS_VALUE
 
-        api = TqApi()
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         quote = api.get_quote("SHFE.cu2006C43000")
         klines = api.get_kline_serial("SHFE.cu2006", 24 * 60 * 60, 30)
         bs_serise = BS_VALUE(klines, quote, 0.025)
@@ -2530,11 +2542,11 @@ def BS_VALUE(df, quote, r=0.025, v=None):
 
     Example2::
 
-        from tqsdk import TqApi
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import BS_VALUE
         from tqsdk.tafunc import get_his_volatility
 
-        api = TqApi()
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         ks = api.get_kline_serial("SHFE.cu2006", 24 * 60 * 60, 30)
         v = get_his_volatility(ks, api.get_quote("SHFE.cu2006"))
         print("历史波动率:", v)
@@ -2589,10 +2601,10 @@ def OPTION_GREEKS(df, quote, r=0.025, v=None):
 
     Example::
 
-        from tqsdk import TqApi
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import OPTION_GREEKS
 
-        api = TqApi()
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         quote = api.get_quote("SHFE.cu2006C44000")
         klines = api.get_kline_serial(["SHFE.cu2006C44000", "SHFE.cu2006"], 24 * 60 * 60, 30)
         greeks = OPTION_GREEKS(klines, quote, 0.025)
@@ -2605,8 +2617,7 @@ def OPTION_GREEKS(df, quote, r=0.025, v=None):
 
     """
     new_df = pd.DataFrame()
-    if not (quote.ins_class.endswith("OPTION") and quote.instrument_id == df["symbol"][0]
-            and quote.underlying_symbol == df["symbol1"][0]):
+    if not (quote.ins_class.endswith("OPTION") and quote.instrument_id == df["symbol"][0] and quote.underlying_symbol == df["symbol1"][0]):
         new_df["delta"] = pd.Series(np.full_like(df["close1"], float('nan')))
         new_df["theta"] = pd.Series(np.full_like(df["close1"], float('nan')))
         new_df["gamma"] = pd.Series(np.full_like(df["close1"], float('nan')))
@@ -2646,10 +2657,10 @@ def OPTION_VALUE(df, quote):
 
     Example::
 
-        from tqsdk import TqApi
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import OPTION_VALUE
 
-        api = TqApi()
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         quote = api.get_quote("SHFE.cu2006C43000")
         klines = api.get_kline_serial(["SHFE.cu2006C43000", "SHFE.cu2006"], 24 * 60 * 60, 30)
         values = OPTION_VALUE(klines, quote)
@@ -2693,18 +2704,17 @@ def OPTION_IMPV(df, quote, r=0.025):
 
     Example::
 
-        from tqsdk import TqApi
+        from tqsdk import TqApi, TqAuth
         from tqsdk.ta import OPTION_IMPV
 
-        api = TqApi()
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
         quote = api.get_quote("SHFE.cu2006C50000")
         klines = api.get_kline_serial(["SHFE.cu2006C50000", "SHFE.cu2006"], 24 * 60 * 60, 20)
         impv = OPTION_IMPV(klines, quote, 0.025)
         print(list(impv["impv"] * 100))
         api.close()
     """
-    if not (quote.ins_class.endswith("OPTION") and quote.instrument_id == df["symbol"][0]
-            and quote.underlying_symbol == df["symbol1"][0]):
+    if not (quote.ins_class.endswith("OPTION") and quote.instrument_id == df["symbol"][0] and quote.underlying_symbol == df["symbol1"][0]):
         return pd.DataFrame(np.full_like(df["close1"], float('nan')), columns=["impv"])
     his_v = tqsdk.tafunc._get_volatility(df["close1"], df["duration"], quote.trading_time)
     his_v = 0.3 if math.isnan(his_v) else his_v
@@ -2712,3 +2722,70 @@ def OPTION_IMPV(df, quote, r=0.025):
     return pd.DataFrame(
         data=list(tqsdk.tafunc.get_impv(df["close1"], df["close"], quote.strike_price, r, his_v, t, quote.option_class)),
         columns=["impv"])
+
+def VOLATILITY_CURVE(df: pd.DataFrame, quotes: dict, underlying: str, r=0.025):
+    """
+    计算期权隐含波动率曲面
+
+    Args:
+        df (pandas.DataFrame): 期权合约及基础标合约组成的多 K 线序列, Dataframe 格式
+
+        quote (dict): 批量获取合约的行情信息, 存储结构必须为 dict, key 为合约, value 为行情数据
+
+                例如: {'SHFE.cu2101':{ ... }, ‘SHFE.cu2101C34000’:{ ... }}
+
+        underlying (str): 基础标的的合约名称, 如 SHFE.cu2101
+
+        r (float): [可选]无风险利率
+
+    Returns:
+        pandas.DataFrame: 返回的 DataFrame
+
+    Example::
+
+        from tqsdk import TqApi, TqAuth
+        from tqsdk.ta import VOLATILITY_CURVE
+
+        api = TqApi(auth=TqAuth("信易账户", "账户密码"))
+        underlying = "DCE.m2101"
+        options = api.query_options(underlying_symbol=underlying, option_class="PUT", expired=False)
+        # 批量获取合约的行情信息, 存储结构必须为 dict, key 为合约, value 为行情数据
+        quote = {}
+        for symbol in options:
+            quote[symbol] = api.get_quote(symbol)
+        options.append(underlying)
+
+        klines = api.get_kline_serial(options, 24 * 60 * 60, 20)
+        vc = VOLATILITY_CURVE(klines, quote, underlying, r = 0.025)
+        print(vc)
+        api.close()
+
+        # 预计的输出是这样的:
+                datetime    2450.0    2500.0  ...  3600.0    3650.0
+        0   1.603382e+18  0.336557  0.314832  ...  0.231657  0.237882
+        1   1.603642e+18  0.353507  0.331051  ...  0.231657  0.237882
+
+    """
+    symbol_titles = [s for s in df.columns.values if s.startswith("symbol")]
+    base_symbol_title = [s for s in symbol_titles if df[s].iloc[0] == underlying]
+    if not base_symbol_title:
+        raise Exception(f"kline 数据中未包含基础标的合约的K线数据, 请更正")
+    base_close_title = f'close{base_symbol_title[0][6:]}'
+
+    res_dict = {} # 波动率曲线数据结构 {'datetime':[], $strike_price:[]}
+    pd_columns = [] # pd.DataFrame 列
+
+    for symbol_title in symbol_titles:
+        if symbol_title == base_symbol_title[0]:
+            continue
+        close_title = f'close{symbol_title[6:]}'
+        quote = quotes[df[symbol_title].iloc[0]]
+        t = tqsdk.tafunc._get_t_series(df["datetime"], df["duration"], quote.expire_datetime)
+        res_dict[quote.strike_price] = tqsdk.tafunc.get_impv(df[base_close_title],
+                                                             df[close_title], quote.strike_price, r, 0.5, t,
+                                                             quote.option_class).interpolate(method='linear')
+        res_dict['datetime'] = df["datetime"]
+        pd_columns.append(quote.strike_price)
+    pd_columns.sort()
+    pd_columns.insert(0, "datetime")
+    return pd.DataFrame(data=res_dict, columns=pd_columns)
